.. UCID documentation master file

Welcome to UCID's documentation!
================================

Urban Context Identifier (UCID) is a production-grade Python library for temporal urban analysis and standardized identifiers.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   instructions/00_project_overview
   instructions/01_installation
   instructions/02_quickstart
   instructions/03_ucid_standard
   api_reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
